==> owncloud-10.2.0.zip: owncloud/settings/l10n/ug.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "__language_name__" : "ئۇيغۇرچە",
    "Language changed" : "تىل ئۆزگەردى",
    "Invalid request" : "ئىناۋەتسىز ئىلتىماس",
    "Admins can't remove themself from the admin group" : "باشقۇرغۇچى ئۆزىنى باشقۇرۇش گۇرۇپپىسىدىن چىقىرىۋېتەلمەيدۇ",
    "All" : "ھەممىسى",
    "Please wait...." : "سەل كۈتۈڭ…",
    "Disable" : "چەكلە",
    "Enable" : "قوزغات",
    "Updating...." : "يېڭىلاۋاتىدۇ…",
    "Error while updating app" : "ئەپنى يېڭىلاۋاتقاندا خاتالىق كۆرۈلدى",
    "Updated" : "يېڭىلاندى",
    "Delete" : "ئۆچۈر",
    "Groups" : "گۇرۇپپا",
    "undo" : "يېنىۋال",
    "never" : "ھەرگىز",
    "add group" : "گۇرۇپپا قوش",
    "enabled" : "قوزغىتىلغان",
    "disabled" : "چەكلەنگەن",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "Forum" : "مۇنبەر",
    "Sharing" : "ھەمبەھىر",
    "Log" : "خاتىرە",
    "None" : "يوق",
    "Login" : "تىزىمغا كىرىڭ",
    "Encryption" : "شىفىرلاش",
    "Server address" : "مۇلازىمېتىر ئادرىسى",
    "Port" : "ئېغىز",
    "Cancel" : "ۋاز كەچ",
    "Email" : "تورخەت",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Password" : "ئىم",
    "Unable to change your password" : "ئىمنى ئۆزگەرتكىلى بولمايدۇ.",
    "Current password" : "نۆۋەتتىكى ئىم",
    "New password" : "يېڭى ئىم",
    "Change password" : "ئىم ئۆزگەرت",
    "Language" : "تىل",
    "Help translate" : "تەرجىمىگە ياردەم",
    "Unlimited" : "چەكسىز",
    "Name" : "ئاتى",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Version" : "نەشرى",
    "Personal" : "شەخسىي",
    "Error" : "خاتالىق",
    "Create" : "قۇر",
    "Other" : "باشقا",
    "set new password" : "يېڭى ئىم تەڭشە",
    "Default" : "كۆڭۈلدىكى",
    "Share" : "ھەمبەھىر",
    "Add" : "قوش"
},
"nplurals=1; plural=0;");

==> owncloud-10.4.1.zip: owncloud/settings/l10n/ug.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "Create" : "قۇر",
    "Delete" : "ئۆچۈر",
    "Share" : "ھەمبەھىر",
    "Language changed" : "تىل ئۆزگەردى",
    "Invalid request" : "ئىناۋەتسىز ئىلتىماس",
    "Admins can't remove themself from the admin group" : "باشقۇرغۇچى ئۆزىنى باشقۇرۇش گۇرۇپپىسىدىن چىقىرىۋېتەلمەيدۇ",
    "All" : "ھەممىسى",
    "Please wait...." : "سەل كۈتۈڭ…",
    "Disable" : "چەكلە",
    "Enable" : "قوزغات",
    "Updating...." : "يېڭىلاۋاتىدۇ…",
    "Error while updating app" : "ئەپنى يېڭىلاۋاتقاندا خاتالىق كۆرۈلدى",
    "Updated" : "يېڭىلاندى",
    "Groups" : "گۇرۇپپا",
    "undo" : "يېنىۋال",
    "Delete group" : "گۇرۇپپا ئۆچۈر",
    "never" : "ھەرگىز",
    "add group" : "گۇرۇپپا قوش",
    "enabled" : "قوزغىتىلغان",
    "disabled" : "چەكلەنگەن",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "Forum" : "مۇنبەر",
    "Language" : "تىل",
    "Sharing" : "ھەمبەھىر",
    "None" : "يوق",
    "Log" : "خاتىرە",
    "Login" : "تىزىمغا كىرىڭ",
    "Encryption" : "شىفىرلاش",
    "Server address" : "مۇلازىمېتىر ئادرىسى",
    "Port" : "ئېغىز",
    "Add" : "قوش",
    "Cancel" : "ۋاز كەچ",
    "Email" : "تورخەت",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Password" : "ئىم",
    "Unable to change your password" : "ئىمنى ئۆزگەرتكىلى بولمايدۇ.",
    "Current password" : "نۆۋەتتىكى ئىم",
    "New password" : "يېڭى ئىم",
    "Change password" : "ئىم ئۆزگەرت",
    "Help translate" : "تەرجىمىگە ياردەم",
    "Name" : "ئاتى",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Version" : "نەشرى",
    "Personal" : "شەخسىي",
    "Other" : "باشقا",
    "Settings" : "تەڭشەكلەر",
    "Unlimited" : "چەكسىز",
    "set new password" : "يېڭى ئىم تەڭشە",
    "Default" : "كۆڭۈلدىكى"
},
"nplurals=1; plural=0;");
